@@ -19,10 +19,10 @@
  ***************************************************************************/
 #include "webquerymathscinet.h"
 
-#include <ntqlayout.h>
-#include <ntqlabel.h>
-#include <ntqregexp.h>
-#include <ntqspinbox.h>
+#include <tqlayout.h>
+#include <tqlabel.h>
+#include <tqregexp.h>
+#include <tqspinbox.h>
 
 #include <kpushbutton.h>
 #include <tdelocale.h>
@@ -32,7 +32,7 @@
 #include <tdeio/netaccess.h>
 #include <tdemessagebox.h>
 
-#include <settings.h>
+#include "settings.h"
 
 namespace KBibTeX
 {
